==> haskell-expiring-cache-map-0.0.6.1-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: expiring-cache-map
version: 0.0.6.1
id: expiring-cache-map-0.0.6.1-AeB3aQEZicHGAExVRGMxk9
key: expiring-cache-map-0.0.6.1-AeB3aQEZicHGAExVRGMxk9
license: BSD3
copyright: (c) 2014 Edward L. Blake
maintainer: edwardlblake@gmail.com
homepage: https://github.com/elblake/expiring-cache-map
synopsis: General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.
category: Caching
author: Edward L. Blake
exposed: True
exposed-modules:
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types
abi: c9024897c11e3a962014e32005aa2ea3
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/expiring-cache-map-0.0.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/expiring-cache-map-0.0.6.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/expiring-cache-map-0.0.6.1
hs-libraries: HSexpiring-cache-map-0.0.6.1-AeB3aQEZicHGAExVRGMxk9
depends:
    base-4.9.0.0 containers-0.5.7.1
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
haddock-interfaces: /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock
haddock-html: /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-expiring-cache-map-0.0.6.1-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-expiring-cache-map.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: expiring-cache-map
version: 0.0.6.1
id: expiring-cache-map-0.0.6.1-247jezs9V085OSuSN01w2
key: expiring-cache-map-0.0.6.1-247jezs9V085OSuSN01w2
license: BSD3
copyright: (c) 2014 Edward L. Blake
maintainer: edwardlblake@gmail.com
homepage: https://github.com/elblake/expiring-cache-map
synopsis: General purpose simple caching.
description:
    A simple general purpose shared state cache map with automatic expiration
    of values, for caching the results of accessing a resource such as reading
    a file. With variations for Ord and Hashable keys using "Data.Map.Strict"
    and "Data.HashMap.Strict", respectively.
category: Caching
author: Edward L. Blake
exposed: True
exposed-modules:
    Caching.ExpiringCacheMap.OrdECM Caching.ExpiringCacheMap.HashECM
    Caching.ExpiringCacheMap.Internal.Internal
    Caching.ExpiringCacheMap.Internal.Types
    Caching.ExpiringCacheMap.Types
    Caching.ExpiringCacheMap.Utils.TestSequence
    Caching.ExpiringCacheMap.Utils.Types
abi: 7ceb51ad2627e6598077f607f23c6899
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/expiring-cache-map-0.0.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/expiring-cache-map-0.0.6.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/expiring-cache-map-0.0.6.1
hs-libraries: HSexpiring-cache-map-0.0.6.1-247jezs9V085OSuSN01w2
depends:
    base-4.9.0.0 containers-0.5.7.1
    hashable-1.2.6.0-CKFo6Z8S7bXH0jokyKXcu0
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
haddock-interfaces: /usr/share/doc/haskell-expiring-cache-map/html/expiring-cache-map.haddock
haddock-html: /usr/share/doc/haskell-expiring-cache-map/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
